@@ -13,7 +13,7 @@ try:
 
 except ModuleNotFoundError:
     sys.path.append('..')
-    from xlsxreader import readxlsx
+    import  xlsxreader
 
 if 'test' in os.listdir('.'):
     os.chdir('./test')
